#--coding:utf-8--
#创建于：2019/4/18 17:08

from distutils.core import setup
setup (
name = 'my_module666666',
version='1.0.0',
author = 'ben',
author_email='62680109@qq.com',

url = 'http://www.xxxxx.com',
description='测试',
py_modules = ['b'],
)
